Jsonnet - The Data Templating Language
Description: The Jsonnet language allows elegant and easy description of JSON data.
Keywords: Jsonnet, JSON, YAML, language, configuration, configuration language, functional, declarative, lazy, structured, elegant, semantics, clean, mixins, inheritance, template, expansion, expand

The data templating language
Jsonnet

1. User docs
   Tutorial Demo Standard Library
2. Case Studies
   Fractal
3. Language
   Design Comparisons Specification
4. Implementation
   Cmdline Tool Libraries C++ Internals Javascript Tests
5. Contributing

# Contributing

## Community

The Google group is a public mailing list that anyone can join to ask questions about or otherwise discuss Jsonnet. We also use the list for release announcements and other relevant communications to Jsonnet users.

There is also an IRC channel: #jsonnet on the freenode network (chat.freenode.net).

## License & Contributions

All Jsonnet implementations are licensed under the Apache 2.0 license.

If you wish to contribute a patch to Jsonnet, do keep us informed as we may be able to help. Please create a fork on Github and do your work there. Before we can merge your pull request, we need you to sign either the Google individual or corporate contributor license agreement (CLA), unless you are a Google employee, intern, or contractor. CLAs are a common requirement when patching open source software projects owned by large companies.

Except as noted, this content is licensed under Creative Commons Attribution 2.5.